@@ -35,28 +35,37 @@ class PharosTargetProvider(StashableBase):
         self.__mU = MarshalUtil(workPath=self.__dirPath)
         reloadDb = kwargs.get("reloadDb", False)
         fromDb = kwargs.get("fromDb", False)
+        useCache = kwargs.get("useCache", False)
+        pharosDumpUrl = kwargs.get("pharosDumpUrl", None)
+        mysqlUser = kwargs.get("mysqlUser", None)
+        mysqlPassword = kwargs.get("mysqlPassword", None)
+        self.__version = None
         if reloadDb or fromDb:
-            self.__reload(self.__dirPath, reloadDb=reloadDb, fromDb=fromDb, **kwargs)
+            self.__reload(self.__dirPath, reloadDb=reloadDb, fromDb=fromDb, useCache=useCache, pharosDumpUrl=pharosDumpUrl, mysqlUser=mysqlUser, mysqlPassword=mysqlPassword)
         #
 
     def testCache(self):
         return True
 
-    def __reload(self, dirPath, reloadDb=False, fromDb=False, **kwargs):
-        startTime = time.time()
-        useCache = kwargs.get("useCache", True)
-        pharosDumpUrl = kwargs.get("pharosDumpUrl", "http://juniper.health.unm.edu/tcrd/download/latest.sql.gz")
+    def getVersion(self):
+        return self.__version
 
+    def __reload(self, dirPath, reloadDb=False, fromDb=False, useCache=False, pharosDumpUrl=None, mysqlUser=None, mysqlPassword=None):
+        startTime = time.time()
+        pharosSelectedTables = ["drug_activity", "cmpd_activity", "target", "protein", "t2tc"]
+        pharosDumpUrl = pharosDumpUrl if pharosDumpUrl else "http://juniper.health.unm.edu/tcrd/download/latest.sql.gz"
+        pharosReadmeUrl = "http://juniper.health.unm.edu/tcrd/download/latest.README"
         ok = False
         fU = FileUtil()
         pharosDumpFileName = fU.getFileName(pharosDumpUrl)
         pharosDumpPath = os.path.join(dirPath, pharosDumpFileName)
+        pharosUpdatePath = os.path.join(dirPath, "pharos-update.sql")
+        pharosReadmePath = os.path.join(dirPath, "pharos-readme.txt")
         logPath = os.path.join(dirPath, "pharosLoad.log")
         #
         fU.mkdir(dirPath)
         #
-        mysqlUser = kwargs.get("mysqlUser", None)
-        mysqlPassword = kwargs.get("mysqlPassword", None)
+
         exU = ExecUtils()
         #
         if reloadDb:
@@ -65,12 +74,27 @@ class PharosTargetProvider(StashableBase):
                 ok = True
             else:
                 logger.info("Fetching url %s path %s", pharosDumpUrl, pharosDumpPath)
-                ok = fU.get(pharosDumpUrl, pharosDumpPath)
-                logger.info("Completed fetch (%r) at %s (%.4f seconds)", ok, time.strftime("%Y %m %d %H:%M:%S", time.localtime()), time.time() - startTime)
+                ok1 = fU.get(pharosDumpUrl, pharosDumpPath)
+                ok2 = fU.get(pharosReadmeUrl, pharosReadmePath)
+                logger.info("Completed fetch (%r) at %s (%.4f seconds)", ok1 and ok2, time.strftime("%Y %m %d %H:%M:%S", time.localtime()), time.time() - startTime)
+            # ---
+            readmeLines = self.__mU.doImport(pharosReadmePath, fmt="list")
+            self.__version = readmeLines[0].split(" ")[1][1:] if readmeLines else "6"
+            # ---
+            logger.info("Filtering SQL dump %r for selected tables %r", pharosDumpFileName, pharosSelectedTables)
+            doWrite = True
+            # Note: the pharos dump file latest.sql.gz is not gzipped
+            with open(pharosDumpPath, "r") as ifh, open(pharosUpdatePath, "w") as ofh:
+                for line in ifh:
+                    if line.startswith("-- Table structure for table"):
+                        tN = line.split(" ")[-1][1:-2]
+                        doWrite = True if tN in pharosSelectedTables else False
+                    if doWrite:
+                        ofh.write(line)
             # ---
             ok = exU.run(
                 "mysql",
-                execArgList=["-v", "-u", mysqlUser, "--password=%s" % mysqlPassword, "-e", "drop database if exists tcrd6; create database tcrd6;"],
+                execArgList=["-v", "-u", mysqlUser, "--password=%s" % mysqlPassword, "-e", "create database if not exists tcrd6;"],
                 outPath=logPath,
                 outAppend=False,
                 timeOut=None,
@@ -83,7 +107,7 @@ class PharosTargetProvider(StashableBase):
             #     outAppend=True,
             #     timeOut=None,
             # )
-            shellCmd = 'trap "" SIGHUP SIGINT SIGTERM; nohup mysql -u %s --password=%s tcrd6 < %s >& %s' % (mysqlUser, mysqlPassword, pharosDumpPath, logPath)
+            shellCmd = 'trap "" SIGHUP SIGINT SIGTERM; nohup mysql -u %s --password=%s tcrd6 < %s >& %s' % (mysqlUser, mysqlPassword, pharosUpdatePath, logPath)
             ok = exU.runShell(
                 shellCmd,
                 outPath=None,
@@ -93,7 +117,7 @@ class PharosTargetProvider(StashableBase):
             )
         # --
         if fromDb:
-            for tbl in ["drug_activity", "cmpd_activity", "target", "protein", "t2tc"]:
+            for tbl in pharosSelectedTables:
                 outPath = os.path.join(dirPath, "%s.tdd" % tbl)
                 if useCache and self.__mU.exists(outPath):
                     continue
@@ -105,7 +129,7 @@ class PharosTargetProvider(StashableBase):
                     timeOut=None,
                     suppressStderr=True,
                 )
-        return True
+        return ok
 
     def exportProteinFasta(self, fastaPath, taxonPath, addTaxonomy=False):
         try:
@@ -156,22 +180,3 @@ class PharosTargetProvider(StashableBase):
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return ok
-
-    def __getTargetDetails(self):
-        # protein.tdd
-        # id	name	description	uniprot	up_version	geneid	sym	family	chr	seq	dtoid	stringid	dtoclass
-        rD = {}
-        try:
-            proteinFilePath = os.path.join(self.__dirPath, "protein.tdd")
-            pDL = self.__mU.doImport(proteinFilePath, fmt="tdd", rowFormat="dict")
-            for pD in pDL:
-                proteinId = pD["id"]
-                unpId = pD["uniprot"] if "uniprot" in pD and pD["uniprot"] != "NULL" else None
-                descr = pD["description"] if "description" in pD and pD["description"] != "NULL" else None
-                geneId = pD["geneid"] if "geneid" in pD and pD["geneid"] != "NULL" else None
-                dtoId = pD["dtoid"] if "dtoid" in pD and pD["dtoid"] != "NULL" else None
-                dtoClass = pD["dtoclass"] if "dtoclass" in pD and pD["dtoclass"] != "NULL" else None
-                rD[proteinId] = {"unpId": unpId, "name": descr, "geneId": geneId, "dtoId": dtoId, "dtoClass": dtoClass}
-        except Exception as e:
-            logger.exception("Failing with %s", str(e))
-        return rD
